#coding=utf-8
from distutils.core import setup

setup(
    name="zhoumingSuperMath",
    version="1.0",   #版本号
    description="这是第一个对外发布的模块，用于测试！",
    author="liupei",
    author_email="liupei@unilumin.cn",
    py_modules=["zhoumingSuperMath.demo1", "zhoumingSuperMath.demo2"]
)